
# Type: has biological sequence


connects a genomic feature to its sequence

URI: [biolink:has_biological_sequence](https://w3id.org/biolink/vocab/has_biological_sequence)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [BiologicalSequence](types/BiologicalSequence.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children

 *  [sequence variant➞has biological sequence](sequence_variant_has_biological_sequence.md)

## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [CodingSequence](CodingSequence.md)
 * [Exon](Exon.md)
 * [Gene](Gene.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [Haplotype](Haplotype.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [MicroRNA](MicroRNA.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [SequenceVariant](SequenceVariant.md)
 * [Transcript](Transcript.md)
